@@ -1,8 +1,9 @@
-use anyhow::{format_err, Error};
 use derive_more::{Display, Into};
 use serde::{Deserialize, Serialize};
 use std::convert::TryFrom;
 
+use crate::{format_string, Error};
+
 /// Relative Humidity as Percent
 #[derive(
     Into, Debug, PartialEq, Copy, Clone, PartialOrd, Serialize, Deserialize, Display, Default,
@@ -16,17 +17,18 @@ impl TryFrom<i64> for Humidity {
         if (0..=100).contains(&item) {
             Ok(Self(item))
         } else {
-            Err(format_err!("{item} is not a valid relative humidity"))
+            Err(Error::InvalidValue(format_string!(
+                "{item} is not a valid relative humidity"
+            )))
         }
     }
 }
 
 #[cfg(test)]
 mod test {
-    use anyhow::Error;
     use std::convert::TryFrom;
 
-    use crate::humidity::Humidity;
+    use crate::{humidity::Humidity, Error};
 
     #[test]
     fn test_humidity() -> Result<(), Error> {
@@ -38,7 +40,7 @@ mod test {
         assert!(h.is_err());
         assert_eq!(
             h.err().unwrap().to_string(),
-            "-86 is not a valid relative humidity"
+            "Invalid Value Error -86 is not a valid relative humidity"
         );
         Ok(())
     }
